@@ -1,5 +1,5 @@
 from abc import ABC
-from GhostScan.CalibrationSessions import CalibrationSession
+from CalibrationSession import CalibrationSession
 
 
 class IntrinsicCalibSession(CalibrationSession, ABC):
