@@ -1,5 +1,5 @@
 from pypylon import pylon
-from GhostScan.Cameras import Camera
+from GhostScan import Camera
 from abc import ABC
 import numpy as np
 import cv2
