@@ -1,6 +1,6 @@
 import numpy as np
 import cv2
-from GhostScan.Cameras import Camera
+from GhostScan import Camera
 import time
 import matplotlib.pyplot as plt
 import sys
