@@ -9,7 +9,7 @@ import time
 # sys.path.insert(0,'..')
 import warnings
 warnings.filterwarnings("ignore", message="module not found")
-from GhostScan.Projections import Projection
+from GhostScan import Projection
 
 
 class Screen(Projection, ABC):
